@@ -36,7 +36,7 @@
 .getGEOSuppFiles <- function(...){
   res <- try({getGEOSuppFiles(...)}, silent = TRUE)
   if (inherits(res, "try-error")) {
-    warning("No internet connection or data source broken.")
+    warning("The data source is temporarily unvailable. Please try it again later or contact the maintainer(s) to solve this issue.")
     rlang::interrupt()
   } else {
     return(res)
