@@ -1,3 +1,4 @@
 #' @importFrom rlang .data
-#' @importFrom methods setGeneric
-utils::globalVariables(".") # This is needed to avoid R CMD check NOTEs
\ No newline at end of file
+#' @importFrom utils globalVariables
+utils::globalVariables(".") # This is needed to avoid R CMD check NOTEs
+pkgEnv <- new.env(parent=emptyenv())
\ No newline at end of file
